import os
# As we use MPI this is necessary to avoid overascribing threads
os.environ['OPENBLAS_NUM_THREADS'] = '1'
from time import time
import pandas as pd
from mpi4py import MPI
import numpy as np


from seismic.correlate.correlate import Correlator
from seismic.trace_data.waveform import Store_Client

comm = MPI.COMM_WORLD

size = comm.Get_size()
rank = comm.Get_rank()

# This gives number of threads, usually twice as many as physical cores
times = []
# Path to the paramter file we created in the step before
params = 'params_benchmark.yaml'
# You don't have to set this (could be None)
# root is the same as proj_dir in params.yaml
root =  '/home/makus/msnoise_compare/data'
os.chdir('/home/makus/msnoise_compare/')
sc = Store_Client('IRIS', root)


for ii in range(5):
    comm.barrier()
    c = Correlator(sc, options=params)
    x = MPI.Wtime()
    st = c.pxcorr()
    times.append(MPI.Wtime()-x)
    if rank == 0:
        for file in os.listdir('data/corr'):
            os.remove(os.path.join('data', 'corr', file))
outfile = 'SeisMIC_times_stackingparallel.csv'
times = np.array(times)
d = {
    'n_cores': np.ones_like(times)*size,
    'processing_time': times}
df = pd.DataFrame(data=d)
if rank == 0:
    if os.path.isfile(outfile):
        # append
        df.to_csv(outfile, mode='a', index=False, header=False)
    else:
        df.to_csv(outfile, mode='w', index=False, header=True)
