import os
os.environ['OPENBLAS_NUM_THREADS'] = '1'
from copy import deepcopy


from mpi4py import MPI
import numpy as np
import pandas as pd
import yaml

from seismic.correlate.correlate import Correlator
from seismic.trace_data.waveform import Store_Client

# Path to the paramter file we created in the step before
params = '/home/makus/vadose_zone/params_speedtest.yaml'
# You don't have to set this (could be None)
client = 'BGR'
# root is the same as proj_dir in params.yaml
root = '/home/makus/vadose_zone/data'

with open(params) as file:
    options = yaml.load(file, Loader=yaml.FullLoader)

stations = ['TANN', 'MULD', 'NEUB', 'ROHR', 'WERN', 'WIMM', 'TRIB', 'FBE']

sc = Store_Client(client, root)


comm = MPI.COMM_WORLD

size = comm.Get_size()
rank = comm.Get_rank()

for ii in [1, 2, 4, 8]:
    options['net']['station'] = stations[:ii]
    if isinstance(options['net']['station'], str):
        n_stat = 1
    else:
        n_stat = len(options['net']['station'])

    c = Correlator(sc, options=deepcopy(options))

    processing_times = []

    for _ in range(5):
        comm.barrier()
        x = MPI.Wtime()
        st = c.pxcorr()

        processing_time = np.array(MPI.Wtime() - x)

        comm.Allreduce(MPI.IN_PLACE, processing_time, MPI.MAX)

        processing_times.append(processing_time)

        # Remove data
        if rank == 0:
            temp_files = os.listdir(os.path.join(root, 'corr'))
            for tf in temp_files:
                os.remove(os.path.join(root, 'corr', tf))

    processing_times = np.array(processing_times)

    # Write processing times to a file
    outfile = '/home/makus/vadose_zone/processing_time_no_stacking.csv'
    if rank == 0:
        d = {
            'n_cores': np.ones_like(processing_times)*size,
            'processing_time': processing_times,
            'n_stats': n_stat}
        df = pd.DataFrame(data=d)
        if os.path.isfile(outfile):
            # append
            df.to_csv(outfile, mode='a', index=False, header=False)
        else:
            df.to_csv(outfile, mode='w', index=False, header=True)
    
